@@ -1,5 +1,6 @@
 # encoding: utf-8
-require 'mail/fields/common/common_field'
+# frozen_string_literal: true
+require 'mail/utilities'
 
 module Mail
   # Provides access to an unstructured header field
@@ -14,63 +15,43 @@ module Mail
   #     field bodies are simply to be treated as a single line of characters
   #     with no further processing (except for header "folding" and
   #     "unfolding" as described in section 2.2.3).
-  class UnstructuredField
-
-    include Mail::CommonField
-    include Mail::Utilities
-
-    attr_accessor :charset
-    attr_reader :errors
-
+  class UnstructuredField < CommonField #:nodoc:
     def initialize(name, value, charset = nil)
-      @errors = []
-
       if value.is_a?(Array)
         # Probably has arrived here from a failed parse of an AddressList Field
         value = value.join(', ')
-      else
-        # Ensure we are dealing with a string
-        value = value.to_s
+
+      # Mark UTF-8 strings parsed from ASCII-8BIT
+      elsif value.respond_to?(:force_encoding) && value.encoding == Encoding::ASCII_8BIT
+        utf8 = value.dup.force_encoding(Encoding::UTF_8)
+        value = utf8 if utf8.valid_encoding?
       end
 
-      if charset
-        self.charset = charset
-      else
+      charset ||=
         if value.respond_to?(:encoding)
-          self.charset = value.encoding
-        else
-          self.charset = $KCODE
+          value.encoding
         end
-      end
-      self.name = name
-      self.value = value
-      self
+
+      super name, value.to_s, charset
     end
 
-    def encoded
-      do_encode
-    end
-
-    def decoded
-      do_decode
-    end
-
-    def default
-      decoded
-    end
-
-    def parse # An unstructured field does not parse
+    # An unstructured field does not parse
+    def parse
       self
     end
 
     private
 
     def do_encode
-      value.nil? ? '' : "#{wrapped_value}\r\n"
+      if value && !value.empty?
+        "#{wrapped_value}\r\n"
+      else
+        ''
+      end
     end
 
     def do_decode
-      value.blank? ? nil : Encodings.decode_encode(value, :decode)
+      Utilities.blank?(value) ? nil : Encodings.decode_encode(value, :decode)
     end
 
     # 2.2.3. Long Header Fields
@@ -120,16 +101,16 @@ module Mail
     def fold(prepend = 0) # :nodoc:
       encoding       = normalized_encoding
       decoded_string = decoded.to_s
-      should_encode  = decoded_string.not_ascii_only?
+      should_encode  = !decoded_string.ascii_only?
       if should_encode
         first = true
         words = decoded_string.split(/[ \t]/).map do |word|
           if first
             first = !first
           else
-            word = " " << word
+            word = " #{word}"
           end
-          if word.not_ascii_only?
+          if !word.ascii_only?
             word
           else
             word.scan(/.{7}|.+$/)
@@ -143,11 +124,18 @@ module Mail
       while !words.empty?
         limit = 78 - prepend
         limit = limit - 7 - encoding.length if should_encode
-        line = ""
+        line = String.new
         first_word = true
         while !words.empty?
           break unless word = words.first.dup
-          word.encode!(charset) if charset && word.respond_to?(:encode!)
+
+          # Convert on 1.9+ only since we aren't sure of the current
+          # charset encoding on 1.8. We'd need to track internal/external
+          # charset on each field.
+          if charset && word.respond_to?(:encoding)
+            word = Encodings.transcode_charset(word, word.encoding, charset)
+          end
+
           word = encode(word) if should_encode
           word = encode_crlf(word)
           # Skip to next line if we're going to go past the limit
@@ -178,7 +166,7 @@ module Mail
     end
 
     def encode(value)
-      value = [value].pack(CAPITAL_M).gsub(EQUAL_LF, EMPTY)
+      value = [value].pack(Constants::CAPITAL_M).gsub(Constants::EQUAL_LF, Constants::EMPTY)
       value.gsub!(/"/,  '=22')
       value.gsub!(/\(/, '=28')
       value.gsub!(/\)/, '=29')
@@ -189,16 +177,13 @@ module Mail
     end
 
     def encode_crlf(value)
-      value.gsub!(CR, CR_ENCODED)
-      value.gsub!(LF, LF_ENCODED)
+      value.gsub!(Constants::CR, Constants::CR_ENCODED)
+      value.gsub!(Constants::LF, Constants::LF_ENCODED)
       value
     end
 
     def normalized_encoding
-      encoding = charset.to_s.upcase.gsub('_', '-')
-      encoding = 'UTF-8' if encoding == 'UTF8' # Ruby 1.8.x and $KCODE == 'u'
-      encoding
+      charset.to_s.upcase.gsub('_', '-')
     end
-
   end
 end
