@@ -2,7 +2,7 @@
 # frozen_string_literal: true
 require 'spec_helper'
 
-describe Mail::Message do
+RSpec.describe Mail::Message do
 
   def basic_email
     "To: mikel\r\nFrom: bob\r\nSubject: Hello!\r\n\r\nemail message\r\n"
@@ -1259,7 +1259,7 @@ describe Mail::Message do
                body 'This is a body of the email'
           end
           mail.add_mime_version("3.0 (This is an unreal version number)")
-          expect(mail.to_s).to match(/Mime-Version: 3.0\r\n/)
+          expect(mail.to_s).to match(/MIME-Version: 3.0\r\n/)
         end
 
         it "should generate a mime version if nothing is passed to add_date" do
@@ -1270,7 +1270,7 @@ describe Mail::Message do
                body 'This is a body of the email'
           end
           mail.add_mime_version
-          expect(mail.to_s).to match(/Mime-Version: 1.0\r\n/)
+          expect(mail.to_s).to match(/MIME-Version: 1.0\r\n/)
         end
 
         it "should make an email and inject a mime_version if none was set if told to_s" do
@@ -1280,7 +1280,7 @@ describe Mail::Message do
             subject 'This is a test email'
                body 'This is a body of the email'
           end
-          expect(mail.to_s).to match(/Mime-Version: 1.0\r\n/)
+          expect(mail.to_s).to match(/MIME-Version: 1.0\r\n/)
         end
 
         it "should add the mime version to the message permanently once sent to_s" do
@@ -1443,7 +1443,7 @@ describe Mail::Message do
           part.body          = 'a' * 999
         end
         mail.encoded
-        
+
         expect(mail.parts.count).to eq(1)
         expect(mail.parts.last.content_transfer_encoding).to match(/7bit|8bit|binary/)
       end
@@ -1471,19 +1471,19 @@ describe Mail::Message do
             end
           end
         end
-        
+
         it "should not add an empty charset header" do
           @mail.charset = nil
-          
+
           expect(@mail.multipart?).to eq true
           expect(@mail.parts.count).to eq 2
           expect(@mail.encoded.scan(/charset=UTF-8/).count).to eq 2
         end
-        
+
         it "should remove the charset header" do
           @mail.charset = 'iso-8859-1'
           @mail.charset = nil
-          
+
           expect(@mail.encoded.scan(/charset=UTF-8/).count).to eq 2
           expect(@mail.encoded.scan(/charset=iso-8859-1/).count).to eq 0
         end
@@ -1507,6 +1507,28 @@ describe Mail::Message do
         end
       end
 
+      describe "add_file sets content_type from attachment" do
+        it "should work if set before body" do
+          m = Mail.new
+          m.add_file :filename=>'a.txt', :content=>'b'
+          m.body 'c'
+          expect(m.parts.first.content_type).to match(/text\/plain/)
+          expect(m.parts.first.body.encoded).to eq('b')
+          expect(m.parts.last.content_type).to match(/text\/plain/)
+          expect(m.parts.last.body.encoded).to eq('c')
+        end
+
+        it "should work if set after body" do
+          m = Mail.new
+          m.body 'c'
+          m.add_file :filename=>'a.txt', :content=>'b'
+          expect(m.parts.first.content_type).to match(/text\/plain/)
+          expect(m.parts.first.body.encoded).to eq('c')
+          expect(m.parts.last.content_type).to match(/text\/plain/)
+          expect(m.parts.last.body.encoded).to eq('b')
+        end
+      end
+
       describe "content-transfer-encoding" do
 
         it "should use 7bit for only US-ASCII chars" do
@@ -1606,7 +1628,7 @@ describe Mail::Message do
           body '<h1>This is HTML</h1>'
         end
       end
-      expect { mail.decoded }.to raise_error(NoMethodError, 'Can not decode an entire message, try calling #decoded on the various fields and body or parts if it is a multipart message.')
+      expect { mail.decoded }.to raise_error(NoMethodError, 'This message cannot be decoded as _entire_ message, try calling #decoded on the various fields and body or parts if it is a multipart message.')
     end
 
     it "should return the decoded body if you call decode and the message is not multipart" do
@@ -1719,23 +1741,19 @@ describe Mail::Message do
       it "should ignore the message id value if self has a nil message id" do
         m1 = Mail.new("To: mikel@test.lindsaar.net\r\nSubject: Yo!\r\n\r\nHello there")
         m2 = Mail.new("To: mikel@test.lindsaar.net\r\nMessage-ID: <1234@test.lindsaar.net>\r\nSubject: Yo!\r\n\r\nHello there")
-
+        expect(m1).to eq m2
         # confirm there are no side-effects in the comparison
         expect(m1[:message_id]).to be_nil
         expect(m2[:message_id].value).to eq '<1234@test.lindsaar.net>'
-
-        expect(m1).to eq m2
       end
 
       it "should ignore the message id value if other has a nil message id" do
         m1 = Mail.new("To: mikel@test.lindsaar.net\r\nMessage-ID: <1234@test.lindsaar.net>\r\nSubject: Yo!\r\n\r\nHello there")
         m2 = Mail.new("To: mikel@test.lindsaar.net\r\nSubject: Yo!\r\n\r\nHello there")
-
+        expect(m1).to eq m2
         # confirm there are no side-effects in the comparison
         expect(m1[:message_id].value).to eq '<1234@test.lindsaar.net>'
         expect(m2[:message_id]).to be_nil
-
-        expect(m1).to eq m2
       end
 
       it "should not be == if both emails have different Message IDs" do
